==> dif-content-manager-db-2.1.5-17-sources.jar: pt/digitalis/dif/content/model/data/NodeAcl.java <==
package pt.digitalis.dif.content.model.data;


import java.util.ArrayList;
import java.util.List;
import pt.digitalis.dif.model.utils.AbstractBeanAttributes;

/**
 * NodeAcl
 * Generated on ORM Generator
 * DIF build process for the Model layer
 *
 */
@SuppressWarnings("serial")
public class NodeAcl extends AbstractBeanAttributes implements java.io.Serializable {

    /** NodeAcl attributes enumeration */
    public static class Fields {
        /** id column */
        public static final String ID = "id";
        /** userId column */
        public static final String USERID = "userId";
        /** groupId column */
        public static final String GROUPID = "groupId";

	    /**
          * List of existing fields
	     *
	     * @return list of field names
	     */
        public static List<String> values() {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("userId");
            list.add("groupId");

            return list;
        }
    }

    /** NodeAcl FK class */
    public static class FK {
        /** node relation */
        public static final String NODE = "node";
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    protected Object getAttributeNoGraphNavigation(String attributeName) {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("node".equalsIgnoreCase(attributeName))
            return node;
        if ("userId".equalsIgnoreCase(attributeName))
            return userId;
        if ("groupId".equalsIgnoreCase(attributeName))
            return groupId;

        return null;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    public void setAttribute(String attributeName, Object attributeValue) {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long)attributeValue;
        if ("node".equalsIgnoreCase(attributeName))
            node = (Node)attributeValue;
        if ("userId".equalsIgnoreCase(attributeName))
            userId = (String)attributeValue;
        if ("groupId".equalsIgnoreCase(attributeName))
            groupId = (String)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** node private attribute */
    private Node node;

    /** userId private attribute */
    private String userId;

    /** groupId private attribute */
    private String groupId;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public NodeAcl() {
    }

	/** 
	 * minimal constructor
	 *
     * @param node
    }
	 */
    public NodeAcl(Node node) {
        this.node = node;
    }

    /**
     * full constructor
	 *
     * @param node
     * @param userId
     * @param groupId
     */
    public NodeAcl(Node node, String userId, String groupId) {
        this.node = node;
        this.userId = userId;
        this.groupId = groupId;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id
     *
     * @return NodeAcl modified instance
     */
    public NodeAcl setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * node getter method
     *
     * @return node method
     */
    public Node getNode() {
        return this.node;
    }
    
    /**       
     * node setter method
     *
     * @param node
     *
     * @return NodeAcl modified instance
     */
    public NodeAcl setNode(Node node) {
        this.node = node;
        
        return this;
    }
    /**       
     * userId getter method
     *
     * @return userId method
     */
    public String getUserId() {
        return this.userId;
    }
    
    /**       
     * userId setter method
     *
     * @param userId
     *
     * @return NodeAcl modified instance
     */
    public NodeAcl setUserId(String userId) {
        this.userId = userId;
        
        return this;
    }
    /**       
     * groupId getter method
     *
     * @return groupId method
     */
    public String getGroupId() {
        return this.groupId;
    }
    
    /**       
     * groupId setter method
     *
     * @param groupId
     *
     * @return NodeAcl modified instance
     */
    public NodeAcl setGroupId(String groupId) {
        this.groupId = groupId;
        
        return this;
    }

    /**
     * Creates a String representation of the NodeAcl object
     *
     * @return the compiled String
     */
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("userId").append("='").append(getUserId()).append("' ");			
        buffer.append("groupId").append("='").append(getGroupId()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the NodeAcl object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(NodeAcl other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("userId".equalsIgnoreCase(attributeName))
        	this.userId = attributeValue;

        if ("groupId".equalsIgnoreCase(attributeName))
        	this.groupId = attributeValue;

    }


}

==> dif-content-manager-db-2.2.0-2-sources.jar: pt/digitalis/dif/content/model/data/NodeAcl.java <==
package pt.digitalis.dif.content.model.data;

import java.util.ArrayList;
import java.util.List;

import pt.digitalis.dif.model.utils.AbstractBeanAttributes;

/**
 * NodeAcl Generated on ORM Generator DIF build process for the Model layer
 */
@SuppressWarnings("serial")
public class NodeAcl extends AbstractBeanAttributes implements java.io.Serializable {

    /** NodeAcl attributes enumeration */
    public static class Fields {

        /** groupId column */
        public static final String GROUPID = "groupId";
        /** id column */
        public static final String ID = "id";
        /** userId column */
        public static final String USERID = "userId";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("userId");
            list.add("groupId");

            return list;
        }
    }

    /** NodeAcl FK class */
    public static class FK {

        /** node relation */
        public static final String NODE = "node";
    }

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
    public synchronized static List<String> getPKFieldList()
    {
        if (pkFieldList == null)
        {
            pkFieldList = new ArrayList<String>();
            pkFieldList.add("id");
        }

        return pkFieldList;
    }

    // Fields

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
    public static String getPKFieldListAsString()
    {
        StringBuffer buffer = new StringBuffer();

        for (int i = 0; i < getPKFieldList().size(); i++)
        {
            if (i != 0)
                buffer.append(",");

            buffer.append(getPKFieldList().get(i));
        }

        return buffer.toString();
    }

    /** groupId private attribute */
    private String groupId;

    /** id private attribute */
    private Long id;

    /** node private attribute */
    private Node node;

    /** userId private attribute */
    private String userId;

    /**
     * default constructor
     */
    public NodeAcl()
    {}

    /**
     * minimal constructor
     *
     * @param node
     *            }
     */
    public NodeAcl(Node node)
    {
        this.node = node;
    }

    /**
     * full constructor
     *
     * @param node
     * @param userId
     * @param groupId
     */
    public NodeAcl(Node node, String userId, String groupId)
    {
        this.node = node;
        this.userId = userId;
        this.groupId = groupId;
    }

    // Constructors

    /**
     * Compares the String representation of the NodeAcl object
     *
     * @param other
     *            The object to compare to
     * @return true of the objects are equal
     */
    public boolean equals(NodeAcl other)
    {
        return this.toString().equals(other.toString());
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
    @Override
    public String getAttributeAsString(String attributeName)
    {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else
        {
            return value.toString().trim();
        }
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    protected Object getAttributeNoGraphNavigation(String attributeName)
    {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("node".equalsIgnoreCase(attributeName))
            return node;
        if ("userId".equalsIgnoreCase(attributeName))
            return userId;
        if ("groupId".equalsIgnoreCase(attributeName))
            return groupId;

        return null;
    }

    // Property accessors

    /**
     * groupId getter method
     *
     * @return groupId method
     */
    public String getGroupId()
    {
        return this.groupId;
    }

    /**
     * id getter method
     *
     * @return id method
     */
    public Long getId()
    {
        return this.id;
    }

    /**
     * node getter method
     *
     * @return node method
     */
    public Node getNode()
    {
        return this.node;
    }

    /**
     * userId getter method
     *
     * @return userId method
     */
    public String getUserId()
    {
        return this.userId;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    public void setAttribute(String attributeName, Object attributeValue)
    {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long) attributeValue;
        if ("node".equalsIgnoreCase(attributeName))
            node = (Node) attributeValue;
        if ("userId".equalsIgnoreCase(attributeName))
            userId = (String) attributeValue;
        if ("groupId".equalsIgnoreCase(attributeName))
            groupId = (String) attributeValue;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue)
    {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("userId".equalsIgnoreCase(attributeName))
            this.userId = attributeValue;

        if ("groupId".equalsIgnoreCase(attributeName))
            this.groupId = attributeValue;

    }

    /**
     * groupId setter method
     *
     * @param groupId
     * @return NodeAcl modified instance
     */
    public NodeAcl setGroupId(String groupId)
    {
        this.groupId = groupId;

        return this;
    }

    /**
     * id setter method
     *
     * @param id
     * @return NodeAcl modified instance
     */
    public NodeAcl setId(Long id)
    {
        this.id = id;

        return this;
    }

    /**
     * node setter method
     *
     * @param node
     * @return NodeAcl modified instance
     */
    public NodeAcl setNode(Node node)
    {
        this.node = node;

        return this;
    }

    /**
     * userId setter method
     *
     * @param userId
     * @return NodeAcl modified instance
     */
    public NodeAcl setUserId(String userId)
    {
        this.userId = userId;

        return this;
    }

    /**
     * Creates a String representation of the NodeAcl object
     *
     * @return the compiled String
     */
    public String toString()
    {
        StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");
        buffer.append("userId").append("='").append(getUserId()).append("' ");
        buffer.append("groupId").append("='").append(getGroupId()).append("' ");
        buffer.append("]");

        return buffer.toString();
    }

}
